<div align="center">
    <a href="https://www.weavel.ai/ape">
        <img src="https://www.dropbox.com/scl/fi/h7e7lunf2x8g0teeqlrlt/Ape-Logo.png?rlkey=fc9fzxye4mls00cluv08f4vus&st=pfjsapa3&raw=1" title="Logo" style="width:200px; padding: 20px;" />
    </a>
    <h1>Meet Ape - your first AI prompt engineer</h1>
    <div>
        <a href="https://pypi.org/project/ape-core" target="_blank">
            <img src="https://img.shields.io/pypi/v/ape-core.svg" alt="PyPI Version"/>
        </a>
    </div>
</div>

## About

`ape-core` is the open source library behind Ape - an AI prompt engineer built by Weavel.

## Installation

```bash
pip install ape-core
```

To enable syntax highlighting for `.prompt` files, you can use the [Promptfile IntelliSense](https://marketplace.visualstudio.com/items?itemName=Weavel.promptfile-intellisense) extension for VS Code.

## Contributing

We welcome contributions to enhance Ape's capabilities and improve its performance. To contribute, please see the [`CONTRIBUTING.md`](CONTRIBUTING.md) file for steps.

## Help and Support

If you have any questions, feedback, or suggestions, please feel free to reach out to us. you can raise an issue in the [issue tracker](https://github.com/weavel-ai/Ape/issues).

 <!-- or join the [discussions](https://github.com/weavel-ai/Ape/discussions) for general discussions. -->

We also have a Discord server for the Ape community, where you can connect with other users, share your experiences, ask questions, and collaborate on the project. To join Weavel's community Discord server, [click here](https://weavel.ai/discord).

## License

`ape-core` is released under the MIT License. See the LICENSE file for more information.

## Credits

Thanks to [Stanford NLP's DSPy](https://github.com/stanfordnlp/dspy) project for the inspiration.
